John Paul Wallington | 16 May 15:41
X-Face
Picon
Favicon

change w3-default-homepage?

Ahoy,

The existing w3-default-homepage is a 404 at cs.indiana.edu.
How about making it w3's page at www.gnu.org?

2008-05-16  John Paul Wallington  <jpw <at> pobox.com>

	* lisp/w3.el (w3-do-setup): Fall back to
	http://www.gnu.org/software/w3/ instead of
	http://www.cs.indiana.edu/elisp/w3/docs.html when setting
	`w3-default-homepage'.

--

-- 
Klaus Straubinger
Joe Corneli | 17 Dec 02:48
Favicon

"Page name is missing" when trying to edit wiki page

I try to edit e.g.

http://planetx.cc.vt.edu/AsteroidMeta/HomePage

by clicking on the "Edit this page" link

http://planetx.cc.vt.edu/AsteroidMeta/?action=edit;id=HomePage

but what comes up is the page

http://planetx.cc.vt.edu/AsteroidMeta/?action=edit

with the error

"Page name is missing"

And this same error comes up if I supply the correct URL by hand.
Klaus Straubinger | 15 Dec 10:16
Picon

wrong font-size calculations in css.el and font.el

The function css-expand-length does not take the default character size
in pixels into account when calculating em and ex values. This results
typically in values very much too large.

I would like to suggest using something like the following in the
condition branch that deals with em and ex values:

    (round (font-spatial-to-canonical
            (concat (number-to-string
                     (* (string-to-number (match-string 1 spec))
                        (if height (frame-char-height) (frame-char-width))))
                    "px")))

I don't know if it is advisable to use font-spatial-to-canonical. But
it could be used in other places in this function too.

By the way, this function font-spatial-to-canonical has another bug:
Pixel values are calculated with

	(setq retval (* num (/ pix-width mm-width) (/ 25.4 72.0))))

instead of the correct

	(setq retval (* num (/ mm-width pix-width) (/ 72.0 25.4))))

i.e., exactly the other way round with respect to dividing and
multiplying.

--

-- 
Klaus Straubinger
(Continue reading)

Klaus Straubinger | 23 Oct 14:01
Picon

w3-download-callback should consider :redirect

The new URL library passes additional arguments in case of a redirect
(:redirect ...). Not only w3-fetch-callback, but also
w3-download-callback should take these into account.

--

-- 
Klaus Straubinger
Ben Pfaff | 26 Mar 19:40
Picon

w3 manual does not permit modification?

The texinfo manual for w3 has the following license notice:

    Permission is granted to make and distribute verbatim copies of
    this manual provided the copyright notice and this permission notice
    are preserved on all copies.

    Permission is granted to process this file through Tex and print the
    results, provided the printed document carries copying permission
    notice identical to this one except for the removal of this paragraph
    (this paragraph not being relevant to the printed manual).

    Permission is granted to make and distribute verbatim copies of@*
    this manual provided the copyright notice and this permission notice@*
    are preserved on all copies.

This doesn't give any permission to modify the manual.  Is this
intentional?  Could you clarify the license?
--

-- 
Ben Pfaff 
email: blp <at> cs.stanford.edu
web: http://benpfaff.org
Arjen P. de Vries | 9 Dec 19:50
Picon
Picon
Favicon

w3-parse.el modification


Hi, 

I use W3 in mh-e to display HTML emails, and since some time it broke
regularly on M$ originating emails, that contain tags in other
namespaces.

I modified w3-parse.el to ignore tags containing ":", a rather ugly hack
but my elisp is very limited.

Maybe you can use it, or implement a better handling of name-spaces,

Regards,

Arjen

Index: w3-parse.el
===================================================================
RCS file: /cvsroot/w3/w3/lisp/w3-parse.el,v
retrieving revision 1.21
diff -u -r1.21 w3-parse.el
--- w3-parse.el 4 Dec 2001 15:49:58 -0000       1.21
+++ w3-parse.el 9 Dec 2005 18:41:26 -0000
@@ -2487,16 +2487,24 @@
                      ;; to set a flag if we see an XML declaration and
                      ;; then treat the EMPTY content model differently
                      ;; below.
+                     ;; Arjen 2005-12-0: a lookup of w3-p-d-tag-name 
(Continue reading)

Yoichi NAKAYAMA | 17 Mar 16:36
X-Face

avoid error caused by an alias of fontset

Hi,
On my environment, font below becomes "fontset-16", which is an alias
of real fontset name. Therefore, following patch is needed to avoid
error on starting Emacs/W3.

Sincerely yours,
-- 
Yoichi NAKAYAMA

--- w3-4.0pre.47/lisp/font.el.orig	2001-11-29 05:04:21.000000000 +0900
+++ w3-4.0pre.47/lisp/font.el	2005-03-18 00:13:01.552391048 +0900
@@ -613,9 +613,13 @@
        (make-font-specifier
 	(face-font-name 'default device)))
     (let ((font (cdr-safe (assq 'font (frame-parameters device)))))
-      (if (and (fboundp 'fontsetp) (fontsetp font))
-	  (aref (get-font-info (aref (cdr (get-fontset-info font)) 0)) 2)
-	font))))
+      (cond ((and (fboundp 'fontsetp) (fontsetp font))
+	     (aref (get-font-info (aref (cdr (get-fontset-info font)) 0)) 2))
+	    ((and (boundp 'fontset-alias-alist)
+		  (rassoc font fontset-alias-alist))
+	     (car (rassoc font fontset-alias-alist)))
+	    (t
+	     font)))))
 	  
 ;;;###autoload
 (defun font-default-object-for-device (&optional device)
Surendra Singhi | 7 Feb 01:49

downloading w3

Hello,
I am trying to download w3 from cvs with the command below, but cvs just 
  keeps connecting & trying to download for hours without doing 
anything. Am I making any mistake?

cvs -z3 -d 
":ext;username=surendrasinghi;hostname=savannah.gnu.org:/cvsroot/w3 " co 
w3 (in directory C:\Xemacs\w3)

Thanks
diff --git a/lisp/w3.el b/lisp/w3.el
index a23131f..af8c4fe 100644
--- a/lisp/w3.el
+++ b/lisp/w3.el
@@ -1852,11 +1852,11 @@ Emacs."
     (or w3-hotlist (w3-parse-hotlist))

     ;; Set the default home page, honoring their defaults, then the
     ;; standard WWW_HOME, then default to the documentation @ IU
     (or w3-default-homepage
 	(setq w3-default-homepage
 	      (or (getenv "WWW_HOME")
-		  "http://www.cs.indiana.edu/elisp/w3/docs.html")))
+		  "http://www.gnu.org/software/w3/")))

     (run-hooks 'w3-load-hook)))
@@ -1852,11 +1852,11 @@ Emacs."

     ;; Set the default home page, honoring their defaults, then the
-    ;; standard WWW_HOME, then default to the documentation @ IU
+    ;; standard WWW_HOME, then default to the w3 page at www.gnu.org
     (or w3-default-homepage
 	(setq w3-default-homepage
(Continue reading)

Magnus Henoch | 1 Mar 00:45
Picon

Emacs/W3 moves from CVS to Git

I just imported the CVS repository of Emacs/W3 into Git.  My aim with
this is to make it easier (for myself and others) to keep separate
branches, and to publish them and merge them.

To get a copy, run:

git clone git://git.sv.gnu.org/w3.git

Or if your firewall only allows HTTP, run:

git clone http://git.sv.gnu.org/r/w3.git

The CVS repository will be shut down at 2008-06-01, so you have three
months to get diffs for any local changes.

Magnus
Magnus Henoch | 17 Nov 14:30
Picon

[bug #21601] Wrong handling of relative links with only query part


URL:
  <http://savannah.gnu.org/bugs/?21601>

                 Summary: Wrong handling of relative links with only query
part
                 Project: w3
            Submitted by: legoscia
            Submitted on: Saturday 11/17/2007 at 14:33
                Category: None
                Severity: 3 - Normal
              Item Group: None
                  Status: None
                 Privacy: Public
             Assigned to: None
             Open/Closed: Open
         Discussion Lock: Any

    _______________________________________________________

Details:

If the page http://foo/bar/baz.html contains a link ?foo, the link should
point to http://foo/bar/baz.html?foo, but W3 currently makes it
http://foo/bar?foo.

    _______________________________________________________

Reply to this item at:

(Continue reading)

Klaus Straubinger | 20 Dec 13:48
Picon

w3-kill-emacs-func

The function w3-kill-emacs-func does not heed the variable
url-history-track when calling url-history-save-history. It
should only do this if (eq url-history-track t), maybe taking
url-history-save-interval also into account.

Furthermore, this function has references to the variable
w3-temporary-directory which does not exist any more. By the way,
the function w3-show-dvi in w3-latex.el has a reference to this
variable as well.

--

-- 
Surendra Singhi

www.public.asu.edu/~sksinghi/

Gmane